# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.api.stac_api import StacApi  # noqa: E501
from arlas_api_python.rest import ApiException


class TestStacApi(unittest.TestCase):
    """StacApi unit test stubs"""

    def setUp(self):
        self.api = arlas_api_python.api.stac_api.StacApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_describe_collection(self):
        """Test case for describe_collection

        Describe the feature collection with id `collectionId`  # noqa: E501
        """
        pass

    def test_get_api(self):
        """Test case for get_api

        OpenAPI  # noqa: E501
        """
        pass

    def test_get_collections(self):
        """Test case for get_collections

        The feature collections in the dataset  # noqa: E501
        """
        pass

    def test_get_conformance_declaration(self):
        """Test case for get_conformance_declaration

        Conformance  # noqa: E501
        """
        pass

    def test_get_feature(self):
        """Test case for get_feature

        Fetch a single feature  # noqa: E501
        """
        pass

    def test_get_features(self):
        """Test case for get_features

        Fetch features  # noqa: E501
        """
        pass

    def test_get_item_search(self):
        """Test case for get_item_search

        Search STAC items with simple filtering.  # noqa: E501
        """
        pass

    def test_get_landing_page(self):
        """Test case for get_landing_page

        Landing page  # noqa: E501
        """
        pass

    def test_post_item_search(self):
        """Test case for post_item_search

        Search STAC items with full-featured filtering.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
